@@ -45,7 +45,7 @@ module Stringex
         return translation unless translation.nil?
 
         if locale != default_locale
-          translate scope, key, options.merge(:locale => default_locale)
+          translate scope, key, options.merge(locale: default_locale)
         else
           default_conversion(scope, key) || options[:default]
         end
@@ -83,7 +83,7 @@ module Stringex
 
       def convert(string, options = {}, &block)
         converter = Converter.new(string, options)
-        converter.instance_exec &block
+        converter.instance_exec(&block)
         converter.smart_strip!
         converter.string
       end
